HiddenLogo class

Hidden Logo widget wrapper. It wraps the body widget and displays a widget built via the provided functions at the top of the screen where it is not visible under the physical hardware barrier.

Inheritance

Constructors

HiddenLogo({required Widget body, required LogoBuilder notchBuilder, required LogoBuilder dynamicIslandBuilder, LogoVisibilityMode visibilityMode = LogoVisibilityMode.always, bool isVisible = true, Key? key})
Hidden Logo widget wrapper. It wraps the body widget and displays a widget built via the provided functions at the top of the screen where it is not visible under the physical hardware barrier.
const

Properties

body → Widget
Your widget to be wrapped (usually MaterialApp or CupertinoApp)
final
dynamicIslandBuilder → LogoBuilder
What would you like to see behind iPhone's Dynamic Island depending on its provided size
final
hashCode → int
The hash code for this object.
no setterinherited
isVisible → bool
You can force hiding of the logo whilst the parameter is set to false
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
notchBuilder → LogoBuilder
What would you like to see behind iPhone's notch depending on its provided size
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visibilityMode → LogoVisibilityMode
Determines when to show your logo
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited